# Installation Instructions

Django AjaxView may be installed from pypi:

```
pip install django-ajaxview
```

Once installed, you'll need to add it to your installed packages in your Django project:

```
INSTALLED_APPS = [
    ...
    'ajaxview'
]
```

That's it.
